Crate native_ipc_testkit

Crate native_ipc_testkit 

Adversarial inputs and cross-platform golden fixtures for native-ipc.

Constants

HOSTILE_U64_BOUNDARIES
Boundary values for hostile relative-offset and declared-length corpora.

Functions

bounded_bit_mutations
Produces at most limit deterministic one-bit hostile mutations.
every_truncation
Produces truncations of input, including the empty and complete input.
golden_message
Encodes a message into an exactly sized owned golden vector.
hostile_layout_mutations
Produces bounded hostile region-header/layout mutations at fixed fields.